package de.w665.biblenotes.db;

import de.w665.biblenotes.db.entity.Role;
import de.w665.biblenotes.db.entity.User;
import de.w665.biblenotes.db.repo.UserRepository;
import jakarta.annotation.PostConstruct;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

@Service
@Slf4j
public class DatabaseInitService {

    @Value("${database.init.create-default-admin-user}")
    private boolean createAdminUser;

    private final UserRepository userRepository;

    public DatabaseInitService(UserRepository userRepository) {
        this.userRepository = userRepository;
    }

    @PostConstruct
    public void init() {
        if(createAdminUser && userRepository.count() == 0) {
            createDefaultAdminUser();
        }
    }

    private void createDefaultAdminUser() {
        log.debug("Inserting admin user...");
        User user = new User();
        user.setUsername("admin");
        user.setPassword("$2a$10$y5u4UL6JwacDrMzXEJqqQO.1Cf3xoZTRhUTab4We/zxnWneI5jTf2");
        user.setEmail("admin@example.com");
        user.setRole(Role.ADMINISTRATOR);
        user.setCreatedAt(LocalDateTime.now());
        user.setUpdatedAt(LocalDateTime.now());
        userRepository.save(user);
        log.debug("Admin user insertion done.");
    }
}
